# PocPoc

[![PyPI version](https://badge.fury.io/py/pocpoc.svg)](https://badge.fury.io/py/pocpoc)\
[![Python version](https://img.shields.io/pypi/pyversions/pocpoc.svg)](https://pypi.python.org/pypi/pocpoc)

A Python library for managing Dependency Injection, Events and Commands, with Redis adapters. It also handles database transactions with the Unit of Work concept using SQLAlchemy adapters.

Installation
------------

You can install the library using pip:

```sh
pip install pocpoc
```

or using poetry:

```sh
poetry add pocpoc
```

Features
--------

- Dependency Injection without decorators
- Redis adapters for Events and Commands
- SQLAlchemy adapter for handling database transactions with the Unit of Work concept

<!-- Documentation
-------------

The full documentation can be found at [https://pocpoc.readthedocs.io/](https://pocpoc.readthedocs.io/). -->

<!-- Contributing
------------

Contributions are welcome! Please read the [contributing guidelines](CONTRIBUTING.md) for more information. -->

License
-------

PocPoc is released under the MIT License. See the [LICENSE](LICENSE) file for more information.
